@@ -1,9 +1,10 @@
 package Config::MVP::Section;
-our $VERSION = '0.092040';
+our $VERSION = '0.092060';
 
 use Moose;
 # ABSTRACT: one section of an MVP configuration sequence
 
+
 has name    => (is => 'ro', isa => 'Str',       required => 1);
 has package => (is => 'ro', isa => 'ClassName', required => 0);
 
@@ -20,9 +21,18 @@ has payload => (
   default  => sub { {} },
 );
 
-sub add_setting {
+has aliases => (
+  is  => 'ro',
+  isa => 'HashRef',
+  default => sub { {} },
+);
+
+sub add_value {
   my ($self, $name, $value) = @_;
 
+  my $alias = $self->aliases->{ $name };
+  $name = $alias if defined $alias;
+
   my $mva = $self->multivalue_args;
 
   if (grep { $_ eq $name } @$mva) {
@@ -52,7 +62,19 @@ Config::MVP::Section - one section of an MVP configuration sequence
 
 =head1 VERSION
 
-version 0.092040
+version 0.092060
+
+=head1 DESCRIPTION
+
+For the most part, you can just consult L<Config::MVP> or
+L<Config::MVP::Assembler>.
+
+Of particular note is the C<aliases> attribute.  It is a hashref.  If the
+aliases hashref is:
+
+  { x => y }
+
+...then attempts to add a value for the name C<x> will add it for C<y> instead.
 
 =head1 AUTHOR
 
